@@ -54,7 +54,8 @@ rvMF <- function (n, mu, k)
     d1 <- d - 1
     v1 <- Rfast::matrnorm(n, d1)
     v <- v1/sqrt(Rfast::rowsums(v1^2))
-    w <- .rvMF64(n,d,k,scModels::chf_1F1(2*k,d1/2,d1))
+    # w <- .rvMF64(n,d,k,scModels::chf_1F1(2*k,d1/2,d1))
+    w <- .rvMF64(n,d,k,.chf(k, d1))
     S <- cbind(sqrt(1 - w^2) * v, w)
     if (isTRUE(all.equal(ini, mu, check.attributes = FALSE))) {
       x <- S
@@ -117,7 +118,8 @@ rvMF <- function (n, mu, k)
 #' G. Marsaglia, W. W. Tsang, and J. Wang. Fast generation of discrete random
 #' variables. \emph{Journal of Statistical Software}, 11(3):1–11, 2004.
 #' @export
-rvMFangle <- function(n,p,kappa) .rvMF64(n,p,kappa,scModels::chf_1F1(2*kappa,(p-1)/2,p-1))
+# rvMFangle <- function(n,p,kappa) .rvMF64(n,p,kappa,scModels::chf_1F1(2*kappa,(p-1)/2,p-1))
+rvMFangle <- function(n,p,kappa) .rvMF64(n,p,kappa,.chf(kappa,p-1))
 
 #' @name vMFangle
 #' @export
